==> italc_1.0.2.orig.tar.gz: italc-1.0.2/ica/resources/de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="de_DE">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/ica_main.cpp" line="293"/>
        <source>iTALC Client on %1:%2</source>
        <translation>iTALC Client auf %1:%2</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="261"/>
        <source>Unable to register service &apos;%1&apos;.</source>
        <translation>Der Dienst &apos;%1&apos; konnte nicht registriert werden.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="289"/>
        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not registered.</source>
        <translation>Es konnte keine Verbindung zum Service-Control-Manager hergestellt werden (haben Sie die nötigen Rechte?!) - der Dienst &apos;%1&apos; wurde nicht registriert.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="320"/>
        <source>The service &apos;%1&apos; is already registered.</source>
        <translation>Der Dienst &apos;%1&apos; ist bereits registriert.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="328"/>
        <source>The service &apos;%1&apos; could not be registered.</source>
        <translation>Der Dienst &apos;%1&apos; konnte nicht registriert werden.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="599"/>
        <source>The service &apos;%1&apos; could not be stopped.</source>
        <translation>Der Dienst &apos;%1&apos; konnte nicht gestoppt werden.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="424"/>
        <source>The service &apos;%1&apos; has been unregistered.</source>
        <translation>Der Dienst &apos;%1&apos; wurde entfernt.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="436"/>
        <source>The service &apos;%1&apos; isn&apos;t registered and therefore can&apos;t be unregistered.</source>
        <translation>Der Dienst &apos;%1&apos; ist nicht registriert und kann daher nicht entfernt werden.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="445"/>
        <source>The service &apos;%1&apos; could not be unregistered.</source>
        <translation>Der Dienst &apos;%1&apos; konnte nicht entfernt werden.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="613"/>
        <source>The service &apos;%1&apos; could not be found.</source>
        <translation>Der Dienst &apos;%1&apos; wurde nicht gefunden.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="472"/>
        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not unregistered.</source>
        <translation>Es konnte keine Verbindung zum Service-Control-Manager hergestellt werden (haben Sie die nötigen Rechte?!) - der Dienst &apos;%1&apos; wurde nicht entfernt.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="629"/>
        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not stopped.</source>
        <translation>Es konnte keine Verbindung zum Service-Control-Manager hergestellt werden (haben Sie die nötigen Rechte?!) - der Dienst &apos;%1&apos; wurde nicht beendet.</translation>
    </message>
    <message>
        <location filename="../../common/src/system_service.cpp" line="361"/>
        <source>The service &apos;%1&apos; was successfully registered.</source>
        <translation>Der Dienst &apos;%1&apos; wurde erfolgreich registriert.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../common/src/local_system.cpp" line="53"/>
        <source>UPL (note for translators: the first three characters of this string are the accellerators (underlined characters) of the three input-fields in logon-dialog of windows - please keep this note as otherwise there are strange errors concerning logon-feature)</source>
        <translation>BKA (note for translators: the first three characters of this string are the accellerators (underlined characters) of the three input-fields in logon-dialog of windows - please keep this note as otherwise there are strange errors concerning logon-feature)</translation>
    </message>
</context>
<context>
    <name>demoClient</name>
    <message>
        <location filename="../src/demo_client.cpp" line="42"/>
        <source>iTALC Demo</source>
        <translation>iTALC Demo</translation>
    </message>
</context>
<context>
    <name>isdServer</name>
    <message>
        <location filename="../src/isd_server.cpp" line="784"/>
        <source>Message from teacher</source>
        <translation>Nachricht vom Lehrer</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="554"/>
        <source>Somebody at host %1 tries to access your screen. Do you want to grant him/her access?</source>
        <translation>Jemand am Rechner %1 versucht auf Ihren Bildschirm zuzugreifen. Möchten Sie ihm/ihr Zugriff gewähren?</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="572"/>
        <source>Never for this session</source>
        <translation>Nie für diese Sitzung</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="567"/>
        <source>Always for this session</source>
        <translation>Immer für diese Sitzung</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="551"/>
        <source>Confirm access</source>
        <translation>Zugriff bestätigen</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="70"/>
        <source>ISD-server error</source>
        <translation>ISD-Server-Fehler</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="75"/>
        <source>The ISD-server could not be started because port %1 is already in use. Please make sure that no other application is using this port and try again.</source>
        <translation>Der ISD-Server konnte nicht gestartet werden, da Port %1 bereits verwendet wird. Bitte stellen Sie sicher, dass kein anderes Programm diesen Port benutzt und versuchen es erneut.</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="850"/>
        <source>Authentication error</source>
        <translation>Authentifizierungsfehler</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="853"/>
        <source>Somebody (IP: %1) tried to access this computer but could not authenticate itself successfully!</source>
        <translation>Jemand (IP:%1) hat versucht, auf diesen Computer zuzugreifen, konnte sich jedoch nicht erfolgreich authentifizieren!</translation>
    </message>
</context>
<context>
    <name>localSystem::QObject</name>
    <message>
        <location filename="../../common/src/local_system.cpp" line="870"/>
        <source>iTALC-snapshots</source>
        <translation>iTALC-Schnappschuesse</translation>
    </message>
</context>
<context>
    <name>messageBox</name>
    <message>
        <location filename="../../common/src/messagebox.cpp" line="75"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>remoteControlWidget</name>
    <message>
        <location filename="../src/remote_control_widget.cpp" line="371"/>
        <source>iTALC remote control (host %1)</source>
        <translation>iTALC Fernsteuerung (Rechner %1)</translation>
    </message>
</context>
<context>
    <name>remoteControlWidgetToolBar</name>
    <message>
        <location filename="../src/remote_control_widget.cpp" line="56"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
</context>
<context>
    <name>vncView</name>
    <message>
        <location filename="../src/vncview.cpp" line="54"/>
        <source>Establishing connection to %1 ...</source>
        <translation>Verbindung zu %1 wird hergestellt ...</translation>
    </message>
</context>
</TS>

==> italc_1.0.7.orig.tar.gz: italc-1.0.7/ica/resources/de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="de_DE">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/system_service.cpp" line="265"/>
        <source>Unable to register service &apos;%1&apos;.</source>
        <translation>Der Dienst &apos;%1&apos; konnte nicht registriert werden.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="293"/>
        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not registered.</source>
        <translation>Es konnte keine Verbindung zum Service-Control-Manager hergestellt werden (haben Sie die nötigen Rechte?!) - der Dienst &apos;%1&apos; wurde nicht registriert.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="324"/>
        <source>The service &apos;%1&apos; is already registered.</source>
        <translation>Der Dienst &apos;%1&apos; ist bereits registriert.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="332"/>
        <source>The service &apos;%1&apos; could not be registered.</source>
        <translation>Der Dienst &apos;%1&apos; konnte nicht registriert werden.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="367"/>
        <source>The service &apos;%1&apos; was successfully registered.</source>
        <translation>Der Dienst &apos;%1&apos; wurde erfolgreich registriert.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="614"/>
        <source>The service &apos;%1&apos; could not be stopped.</source>
        <translation>Der Dienst &apos;%1&apos; konnte nicht gestoppt werden.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="434"/>
        <source>The service &apos;%1&apos; has been unregistered.</source>
        <translation>Der Dienst &apos;%1&apos; wurde entfernt.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="450"/>
        <source>The service &apos;%1&apos; isn&apos;t registered and therefore can&apos;t be unregistered.</source>
        <translation>Der Dienst &apos;%1&apos; ist nicht registriert und kann daher nicht entfernt werden.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="460"/>
        <source>The service &apos;%1&apos; could not be unregistered.</source>
        <translation>Der Dienst &apos;%1&apos; konnte nicht entfernt werden.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="628"/>
        <source>The service &apos;%1&apos; could not be found.</source>
        <translation>Der Dienst &apos;%1&apos; wurde nicht gefunden.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="487"/>
        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not unregistered.</source>
        <translation>Es konnte keine Verbindung zum Service-Control-Manager hergestellt werden (haben Sie die nötigen Rechte?!) - der Dienst &apos;%1&apos; wurde nicht entfernt.</translation>
    </message>
    <message>
        <location filename="../src/system_service.cpp" line="644"/>
        <source>The Service Control Manager could not be contacted (do you have the neccessary rights?!) - the service &apos;%1&apos; was not stopped.</source>
        <translation>Es konnte keine Verbindung zum Service-Control-Manager hergestellt werden (haben Sie die nötigen Rechte?!) - der Dienst &apos;%1&apos; wurde nicht beendet.</translation>
    </message>
    <message>
        <location filename="../src/ica_main.cpp" line="296"/>
        <source>iTALC Client %1 on %2:%3</source>
        <translation>iTALC Client %1 auf %2:%3</translation>
    </message>
</context>
<context>
    <name>demoClient</name>
    <message>
        <location filename="../src/demo_client.cpp" line="44"/>
        <source>iTALC Demo</source>
        <translation>iTALC Demo</translation>
    </message>
</context>
<context>
    <name>isdServer</name>
    <message>
        <location filename="../src/isd_server.cpp" line="768"/>
        <source>Message from teacher</source>
        <translation>Nachricht vom Lehrer</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="570"/>
        <source>Somebody at host %1 tries to access your screen. Do you want to grant him/her access?</source>
        <translation>Jemand am Rechner %1 versucht auf Ihren Bildschirm zuzugreifen. Möchten Sie ihm/ihr Zugriff gewähren?</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="573"/>
        <source>Never for this session</source>
        <translation>Nie für diese Sitzung</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="575"/>
        <source>Always for this session</source>
        <translation>Immer für diese Sitzung</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="567"/>
        <source>Confirm access</source>
        <translation>Zugriff bestätigen</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="68"/>
        <source>ISD-server error</source>
        <translation>ISD-Server-Fehler</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="73"/>
        <source>The ISD-server could not be started because port %1 is already in use. Please make sure that no other application is using this port and try again.</source>
        <translation>Der ISD-Server konnte nicht gestartet werden, da Port %1 bereits verwendet wird. Bitte stellen Sie sicher, dass kein anderes Programm diesen Port benutzt und versuchen es erneut.</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="824"/>
        <source>Authentication error</source>
        <translation>Authentifizierungsfehler</translation>
    </message>
    <message>
        <location filename="../src/isd_server.cpp" line="827"/>
        <source>Somebody (IP: %1) tried to access this computer but could not authenticate itself successfully!</source>
        <translation>Jemand (IP:%1) hat versucht, auf diesen Computer zuzugreifen, konnte sich jedoch nicht erfolgreich authentifizieren!</translation>
    </message>
</context>
</TS>
